@@ -84,6 +84,42 @@ static Token* parseString(Token *tok, char **out)
 		*out = parseStringLiteral(tok->value);
 		return tok->next;
 	}
+	else if (strcmp(tok->value, "@") == 0)
+	{
+		char *cmd;
+		
+		tok = tok->next;
+		tok = parseString(tok, &cmd);
+		
+		FILE *fp = popen(cmd, "r");
+		free(cmd);
+		
+		if (fp == NULL)
+		{
+			*out = "<popen failed>";
+			return tok;
+		};
+		
+		char buffer[4096];
+		char *put = buffer;
+		int spaceLeft = 4095;
+		
+		while (1)
+		{
+			int count = fread(put, 1, spaceLeft, fp);
+			if (count == 0) break;
+			put += count;
+		};
+		
+		*put = 0;
+		pclose(fp);
+		
+		char *endline = strchr(buffer, '\n');
+		if (endline != NULL) *endline = 0;
+		
+		*out = strdup(buffer);
+		return tok;
+	}
 	else if (strcmp(tok->value, "(") == 0)
 	{
 		char *result = (char*) malloc(1);
